mod alias;
mod append;
mod autoenv;
mod autoenv_trust;
mod autoenv_untrust;
mod cal;
mod cd;
mod compact;
mod count;
mod cp;
mod default;
mod drop;
mod each;
mod echo;
mod empty;
mod enter;
mod every;
mod first;
mod format;
mod get;
mod group_by;
mod headers;
mod histogram;
mod insert;
mod into_int;
mod keep;
mod last;
mod lines;
mod ls;
mod math;
mod merge;
mod mkdir;
mod move_;
mod open;
mod parse;
mod prepend;
mod random;
mod range;
mod reduce;
mod rename;
mod reverse;
mod rm;
mod save;
mod select;
mod semicolon;
mod skip;
mod sort_by;
mod split_by;
mod split_column;
mod split_row;
mod str_;
mod touch;
mod uniq;
mod update;
mod where_;
mod with_env;
mod wrap;
